@@ -3,7 +3,9 @@ use Evo '-Export *';
 use Evo::Comp::Hash ();
 export_proxy('Evo::Comp::Hash', '*');
 
-sub import($me, @args) { export_install_in(scalar caller, $me, @args ? @args : '*') }
+sub import ($me, @args) {
+  export_install_in(scalar caller, $me, @args ? @args : '*');
+}
 
 1;
 
@@ -19,7 +21,7 @@ Evo::Comp
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 DESCRIPTION
 
