@@ -2,7 +2,9 @@ package Evo::Comp::Hash;
 use Evo '-Export *';
 use Evo '::Gen::Hash GEN; -Role ROLE_EXPORTER; ::Meta';
 
-sub import($me, @args) { export_install_in(scalar caller, $me, @args ? @args : '*') }
+sub import ($me, @args) {
+  export_install_in(scalar caller, $me, @args ? @args : '*');
+}
 
 my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
 
@@ -20,7 +22,7 @@ export_gen overrides => sub($class) {
   sub { $META->mark_overriden($class, @_); };
 };
 
-export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
+export_anon MODIFY_CODE_ATTRIBUTES => sub ($class, $code, @attrs) {
   my @bad = grep { $_ ne 'Override' } @attrs;
   return @bad if @bad;
 
@@ -43,7 +45,7 @@ Evo::Comp::Hash
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 DESCRIPTION
 
