@@ -4,7 +4,9 @@ use Evo '::Gen::HUF GEN; -Role ROLE_EXPORTER; ::Meta';
 
 my $META = Evo::Comp::Meta::new(gen => GEN, rex => ROLE_EXPORTER);
 
-sub import($me, @args) { export_install_in(scalar caller, $me, @args ? @args : '*') }
+sub import ($me, @args) {
+  export_install_in(scalar caller, $me, @args ? @args : '*');
+}
 
 export_gen init => sub { $META->compile_builder(shift); };
 
@@ -21,7 +23,7 @@ export_gen overrides => sub($class) {
 };
 
 
-export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
+export_anon MODIFY_CODE_ATTRIBUTES => sub ($class, $code, @attrs) {
   my @bad = grep { $_ ne 'Override' } @attrs;
   return @bad if @bad;
 
@@ -45,7 +47,7 @@ Evo::Comp::Out
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 DESCRIPTION
 
