@@ -7,12 +7,12 @@ Evo::Export::Exporter::DEFAULT->add_sub(__PACKAGE__, $_) for @EXPORT;
 
 sub import { export_install_in(scalar caller, @_); }
 
-sub export_install_in($dst, $src, @list) {
+sub export_install_in ($dst, $src, @list) {
   Evo::Export::Exporter::DEFAULT->install($src, $dst, @list) if @list;
 }
 
 # pay attention: without provided name all aliases will be found by _find_subnames and exported
-sub MODIFY_CODE_ATTRIBUTES($pkg, $code, @attrs) {
+sub MODIFY_CODE_ATTRIBUTES ($pkg, $code, @attrs) {
   my (@bad, @good);
   foreach my $attr (@attrs) {
     my ($attr_name, $val) = _parse_attr($attr);
@@ -34,10 +34,14 @@ sub _parse_attr($attr) {
 }
 
 
-sub _add_gen($name, $gen) { Evo::Export::Exporter::DEFAULT->add_gen(__PACKAGE__, $name, $gen); }
+sub _add_gen ($name, $gen) {
+  Evo::Export::Exporter::DEFAULT->add_gen(__PACKAGE__, $name, $gen);
+}
 
 _add_gen export_gen => sub($dst) {
-  sub($name, $gen) { Evo::Export::Exporter::DEFAULT->add_gen($dst, $name, $gen) }
+  sub ($name, $gen) {
+    Evo::Export::Exporter::DEFAULT->add_gen($dst, $name, $gen);
+    }
 };
 
 _add_gen export_anon => sub($dst) {
@@ -52,7 +56,9 @@ _add_gen export => sub($dst) {
 };
 
 _add_gen export_proxy => sub($dst) {
-  sub($epkg,@list) { Evo::Export::Exporter::DEFAULT->proxy($dst, $epkg, @list); }
+  sub ($epkg, @list) {
+    Evo::Export::Exporter::DEFAULT->proxy($dst, $epkg, @list);
+    }
 };
 
 1;
@@ -69,7 +75,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 DESCRIPTION
 
