@@ -7,7 +7,9 @@ use Module::Load 'load';
 
 our @CARP_NOT = ('Evo::Lib::Bare');
 
-sub import($me, @args) { export_install_in(scalar caller, $me, @args ? @args : '*') }
+sub import ($me, @args) {
+  export_install_in(scalar caller, $me, @args ? @args : '*');
+}
 
 use constant ROLE_EXPORTER => Evo::Role::Exporter::new();
 export 'ROLE_EXPORTER';
@@ -41,7 +43,7 @@ export_gen requires => sub($role_class) {
 };
 
 
-export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
+export_anon MODIFY_CODE_ATTRIBUTES => sub ($class, $code, @attrs) {
   my @bad = grep { $_ ne 'Role' } @attrs;
   return @bad if @bad;
 
@@ -52,7 +54,7 @@ export_anon MODIFY_CODE_ATTRIBUTES => sub($class, $code, @attrs) {
 
 1;
 
-our $VERSION = '0.0205';    # VERSION
+our $VERSION = '0.0206';    # VERSION
 
 # ABSTRACT: Evo::Role - reuse code between components
 
@@ -68,7 +70,7 @@ Evo::Role - Evo::Role - reuse code between components
 
 =head1 VERSION
 
-version 0.0205
+version 0.0206
 
 =head1 DESCRIPTION
 
